﻿//-----------------------------------------------------------------------------
//
//  options.cs
//
//  USB Performance Monitor Application
//  Copyright (C) 2010 Simon Inns
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//  Web:    http://www.waitingforfriday.com
//  Email:  simon.inns@gmail.com
//
//-----------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.Diagnostics;

namespace USB_Performance_Monitor
    {
    public partial class options : Form
        {
        public options()
            {
            InitializeComponent();
            }

        // Trackbar value changed label updates --------------------------------------------------------------------------

        // Meter Update Speed Track Bar value changed
        private void meterUpdateSpeedTrackBar_valueChanged(object sender, EventArgs e)
            {
            updateTrackbarValueLabels();
            }

        // Left meter sensitivity track bar value changed
        private void leftMeterSensitivityTrackBar_valueChanged(object sender, EventArgs e)
            {
            updateTrackbarValueLabels();
            }

        // Right meter sensitivity track bar value changed
        private void rightMeterSensitivityTrackBar_valueChanged(object sender, EventArgs e)
            {
            updateTrackbarValueLabels();
            }

        // HDD Fade on speed track bar value changed
        private void hddFadeOnSpeedTrackBar_valueChanged(object sender, EventArgs e)
            {
            updateTrackbarValueLabels();
            }

        // HDD Fade off speed track bar value changed
        private void hddFadeOffSpeedTrackBar_valueChanged(object sender, EventArgs e)
            {
            updateTrackbarValueLabels();
            }

        // Update all of the trackbar value labels
        private void updateTrackbarValueLabels()
            {
            // Update the Meter Update Speed trackbar's label
            if (meterUpdateSpeedTrackBar.Value < 10)
                this.meterUpdateSpeedValueLabel.Text = String.Concat("0.", meterUpdateSpeedTrackBar.Value, " Seconds");
            else this.meterUpdateSpeedValueLabel.Text = "1.0 Second";

            // Update the Left meter sensitivity trackbar's label
            this.leftMeterSensitivityValueLabel.Text = String.Concat(leftMeterSensitivityTrackBar.Value, "%");

            // Update the Right meter sensitivity trackbar's label
            this.rightMeterSensitivityValueLabel.Text = String.Concat(rightMeterSensitivityTrackBar.Value, "%");

            // Update the HDD Fade on speed trackbar's label
            if (hddFadeOnSpeedTrackBar.Value < 10)
                this.hddFadeOnSpeedValueLabel.Text = String.Concat("0.", hddFadeOnSpeedTrackBar.Value, " Seconds");
            else this.hddFadeOnSpeedValueLabel.Text = String.Concat("1.0 Second");

            // Update the HDD Fade off speed trackbar's label
            if (hddFadeOffSpeedTrackBar.Value < 10)
                this.hddFadeOffSpeedValueLabel.Text = String.Concat("0.", hddFadeOffSpeedTrackBar.Value, " Seconds");
            else this.hddFadeOffSpeedValueLabel.Text = String.Concat("1.0 Second");
            }

        // Dialogue Form Buttons ------------------------------------------------------------------------------------------------

        private void cancelButton_Click(object sender, EventArgs e)
            {
            // Close the options dialogue
            this.DialogResult = DialogResult.OK;
            }

        // Save button clicked
        private void saveButton_Click(object sender, EventArgs e)
            {
            // Persist changes to options
            Properties.Settings.Default.Save();

            // Close the options dialogue
            this.DialogResult = DialogResult.OK;
            }

        // Restore defaults button clicked
        private void restoreDefaultsButton_Click(object sender, EventArgs e)
            {
            // Show the 'are you sure' message
            switch (MessageBox.Show("This will override your settings with the application's default settings.  This action cannot be undone.  Are you sure?",
                "Restore Default Settings",
                MessageBoxButtons.YesNo,
                MessageBoxIcon.Warning))
                {
                case DialogResult.Yes:
                    // Reset the user's settings
                    Properties.Settings.Default.Reset();

                    // Update any form items that are not automatically bound to the applications settings
                    this.hddReadColourComboBox.SelectedItem = Properties.Settings.Default.hddLedReadColour;
                    this.hddWriteColourComboBox.SelectedItem = Properties.Settings.Default.hddLedWriteColour;
                    this.hddRwColourComboBox.SelectedItem = Properties.Settings.Default.hddLedRwColour;

                    setLeftMeterRadioButtons();
                    setRightMeterRadioButtons();
                    setButtonRadioButtons();
                    break;

                case DialogResult.No:
                    // No action
                    break;
                }
            }

        // Combobox methods -----------------------------------------------------------------------------------------------------

        // HDD Write colour combo box changed
        private void hddWriteColourComboBox_SelectedIndexChanged(object sender, EventArgs e)
            {
            Properties.Settings.Default.hddLedWriteColour = this.hddWriteColourComboBox.SelectedItem.ToString();
            }

        // HDD Read colour combo box changed
        private void hddReadColourComboBox_SelectedIndexChanged(object sender, EventArgs e)
            {
            Properties.Settings.Default.hddLedReadColour = this.hddReadColourComboBox.SelectedItem.ToString();
            }

        // HDD RW colour combo box changed
        private void hddRwColourComboBox_SelectedIndexChanged(object sender, EventArgs e)
            {
            Properties.Settings.Default.hddLedRwColour = this.hddRwColourComboBox.SelectedItem.ToString();
            }

        // Misc form methods ----------------------------------------------------------------------------------------------------

        // Options dialogue loaded
        private void options_Load(object sender, EventArgs e)
            {
            // We want to default the form to the application settings each time it's loaded
            Properties.Settings.Default.Reload();

            // Sanity check the performance counter instances to make sure any monitored devices
            // have not been unplugged (like USB thumbdrives etc)
            if (String.Compare(Properties.Settings.Default.leftMeterInstance, "") != 0)
                {
                // Left meter instance is set, check it still exists
                string counterCategory = null;
                switch (Properties.Settings.Default.leftMeterFunction)
                    {
                    case "Processor":
                        counterCategory = "Processor";
                        break;
                    case "Harddrive":
                        counterCategory = "PhysicalDisk";
                        break;
                    case "Memory":
                        counterCategory = "Memory";
                        break;
                    case "Network":
                        counterCategory = "Network Interface";
                        break;
                    case "Disabled":
                        counterCategory = "Disabled";
                        break;
                    }

                if (String.Compare(counterCategory, "Disabled") != 0 && String.Compare(counterCategory, "Memory") != 0)
                    {
                    string[] instanceNames;
                    PerformanceCounterCategory leftPerformanceCounterCategory =
                        new PerformanceCounterCategory(counterCategory);

                    instanceNames = leftPerformanceCounterCategory.GetInstanceNames();

                    bool stillExists = false;
                    foreach (string categoryInstance in instanceNames)
                        {
                        if (String.Compare(categoryInstance, Properties.Settings.Default.leftMeterInstance) == 0) stillExists = true;
                        }

                    if (!stillExists)
                        {
                        // Instance has been removed, reset left meter to default
                        Properties.Settings.Default.leftMeterFunction = "Processor";
                        Properties.Settings.Default.leftMeterInstanceFunction = "Processor";
                        Properties.Settings.Default.leftMeterInstance = "_Total";

                        // Persist changes to options
                        Properties.Settings.Default.Save();

                        // Warn the user
                        MessageBox.Show("The instance monitored by the left meter has been removed.  The left meter has been set to the default settings.",
                            "UPM - Left meter reset",
                            MessageBoxButtons.OK,
                            MessageBoxIcon.Information);
                        }
                    }
                }

            if (String.Compare(Properties.Settings.Default.rightMeterInstance, "") != 0)
                {
                // Right meter instance is set, check it still exists
                string counterCategory = null;
                switch (Properties.Settings.Default.rightMeterFunction)
                    {
                    case "Processor":
                        counterCategory = "Processor";
                        break;
                    case "Harddrive":
                        counterCategory = "PhysicalDisk";
                        break;
                    case "Memory":
                        counterCategory = "Memory";
                        break;
                    case "Network":
                        counterCategory = "Network Interface";
                        break;
                    case "Disabled":
                        counterCategory = "Disabled";
                        break;
                    }

                if (String.Compare(counterCategory, "Disabled") != 0 && String.Compare(counterCategory, "Memory") != 0)
                    {
                    string[] instanceNames;
                    PerformanceCounterCategory rightPerformanceCounterCategory =
                        new PerformanceCounterCategory(counterCategory);

                    instanceNames = rightPerformanceCounterCategory.GetInstanceNames();

                    bool stillExists = false;
                    foreach (string categoryInstance in instanceNames)
                        {
                        if (String.Compare(categoryInstance, Properties.Settings.Default.rightMeterInstance) == 0) stillExists = true;
                        }

                    if (!stillExists)
                        {
                        // Instance has been removed, reset right meter to default
                        Properties.Settings.Default.rightMeterFunction = "Harddrive";
                        Properties.Settings.Default.rightMeterInstanceFunction = "Harddrive";
                        Properties.Settings.Default.rightMeterInstance = "_Total";

                        // Persist changes to options
                        Properties.Settings.Default.Save();

                        // Warn the user
                        MessageBox.Show("The instance monitored by the right meter has been removed.  The right meter has been set to the default settings.",
                            "UPM - Right meter reset",
                            MessageBoxButtons.OK,
                            MessageBoxIcon.Information);
                        }
                    }
                }

            // Populate the HDD LED Colour selection comboboxes
            this.hddReadColourComboBox.Items.Add("Amber");
            this.hddReadColourComboBox.Items.Add("Blue");
            this.hddReadColourComboBox.Items.Add("Green");
            this.hddReadColourComboBox.Items.Add("Purple");
            this.hddReadColourComboBox.Items.Add("Red");
            this.hddReadColourComboBox.Items.Add("White");
            this.hddReadColourComboBox.Items.Add("Yellow");

            // Load the application setting for the LED colour
            this.hddReadColourComboBox.SelectedItem = Properties.Settings.Default.hddLedReadColour;

            this.hddWriteColourComboBox.Items.Add("Amber");
            this.hddWriteColourComboBox.Items.Add("Blue");
            this.hddWriteColourComboBox.Items.Add("Green");
            this.hddWriteColourComboBox.Items.Add("Purple");
            this.hddWriteColourComboBox.Items.Add("Red");
            this.hddWriteColourComboBox.Items.Add("White");
            this.hddWriteColourComboBox.Items.Add("Yellow");

            // Load the application setting for the LED colour
            this.hddWriteColourComboBox.SelectedItem = Properties.Settings.Default.hddLedWriteColour;

            this.hddRwColourComboBox.Items.Add("Amber");
            this.hddRwColourComboBox.Items.Add("Blue");
            this.hddRwColourComboBox.Items.Add("Green");
            this.hddRwColourComboBox.Items.Add("Purple");
            this.hddRwColourComboBox.Items.Add("Red");
            this.hddRwColourComboBox.Items.Add("White");
            this.hddRwColourComboBox.Items.Add("Yellow");

            // Load the application setting for the LED colour
            this.hddRwColourComboBox.SelectedItem = Properties.Settings.Default.hddLedRwColour;

            // Set the meter function radio buttons
            setLeftMeterRadioButtons();
            setRightMeterRadioButtons();

            // Set the button function radio buttons
            setButtonRadioButtons();
            }

        // Radiobutton methods --------------------------------------------------------------------------------------------------

        // Left Meter methods
        private void leftMeterProcessorUtilisationRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (this.leftMeterProcessorUtilisationRadioButton.Checked == true)
                {
                Properties.Settings.Default.leftMeterFunction = "Processor";

                // Update the instances combobox
                setLeftMeterInstance("Processor");
                if (leftMeterInstanceComboBox.SelectedItem != null)
                    Properties.Settings.Default.leftMeterInstance = leftMeterInstanceComboBox.SelectedItem.ToString();
                }
            }

        private void leftMeterHardDriveUtilisationRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (this.leftMeterHardDriveUtilisationRadioButton.Checked == true)
                {
                Properties.Settings.Default.leftMeterFunction = "Harddrive";

                // Update the instances combobox
                setLeftMeterInstance("PhysicalDisk");
                if (leftMeterInstanceComboBox.SelectedItem != null)
                    Properties.Settings.Default.leftMeterInstance = leftMeterInstanceComboBox.SelectedItem.ToString();
                }
            }

        private void leftMeterMemoryUtilisationRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (this.leftMeterMemoryUtilisationRadioButton.Checked == true)
                {
                Properties.Settings.Default.leftMeterFunction = "Memory";

                // Update the instances combobox
                setLeftMeterInstance("Memory");
                if (leftMeterInstanceComboBox.SelectedItem != null)
                    Properties.Settings.Default.leftMeterInstance = leftMeterInstanceComboBox.SelectedItem.ToString();
                }
            }

        private void leftMeterNetworkUtilisationRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (this.leftMeterNetworkUtilisationRadioButton.Checked == true)
                {
                Properties.Settings.Default.leftMeterFunction = "Network";

                // Update the instances combobox
                setLeftMeterInstance("Network Interface");
                if (leftMeterInstanceComboBox.SelectedItem != null)
                    Properties.Settings.Default.leftMeterInstance = leftMeterInstanceComboBox.SelectedItem.ToString();

                // Enable the bandwidth override dialogue
                this.leftOverrideNetworkMaximumBandwidthCheckBox.Enabled = true;
                this.leftOverrideNetworkMaximumBandwidthMaskedTextBox.Enabled = true;
                this.leftMbitsSecLabel.Enabled = true;
                }
            else
                {
                // Disable the bandwidth override dialogue
                this.leftOverrideNetworkMaximumBandwidthCheckBox.Enabled = false;
                this.leftOverrideNetworkMaximumBandwidthMaskedTextBox.Enabled = false;
                this.leftMbitsSecLabel.Enabled = false;
                }
            }

        private void leftMeterDisabledRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (this.leftMeterDisabledRadioButton.Checked == true)
                {
                Properties.Settings.Default.leftMeterFunction = "Disabled";

                // Clear the combobox
                this.leftMeterInstanceComboBox.Items.Clear();

                // Disable the instance combobox
                this.leftMeterInstanceComboBox.Enabled = false;
                }
            }

        private void setLeftMeterRadioButtons()
            {
            switch (Properties.Settings.Default.leftMeterFunction)
                {
                case "Processor":
                    this.leftMeterProcessorUtilisationRadioButton.Checked = true;
                    
                    // Update the instances combobox
                    setLeftMeterInstance("Processor");
                    this.leftMeterInstanceComboBox.SelectedItem = Properties.Settings.Default.leftMeterInstance;
                    break;

                case "Harddrive":
                    this.leftMeterHardDriveUtilisationRadioButton.Checked = true;
                    
                    // Update the instances combobox
                    setLeftMeterInstance("PhysicalDisk");
                    this.leftMeterInstanceComboBox.SelectedItem = Properties.Settings.Default.leftMeterInstance;
                    break;

                case "Memory":
                    this.leftMeterMemoryUtilisationRadioButton.Checked = true;

                    // Update the instances combobox
                    setLeftMeterInstance("Memory");
                    this.leftMeterInstanceComboBox.SelectedItem = Properties.Settings.Default.leftMeterInstance;
                    break;

                case "Network":
                    this.leftMeterNetworkUtilisationRadioButton.Checked = true;

                    // Update the instances combobox
                    setLeftMeterInstance("Network Interface");
                    this.leftMeterInstanceComboBox.SelectedItem = Properties.Settings.Default.leftMeterInstance;
                    break;

                case "Disabled":
                    this.leftMeterDisabledRadioButton.Checked = true;

                    // Disable the instance combobox
                    this.leftMeterInstanceComboBox.Enabled = false;
                    break;
                }
            }

        private void setLeftMeterInstance(string counterCategory)
            {
            // Update the instances combobox
            string[] instanceNames;
            PerformanceCounterCategory myPerformanceCounterCategory =
                new PerformanceCounterCategory(counterCategory);

            instanceNames = myPerformanceCounterCategory.GetInstanceNames();

            if (instanceNames.Length == 0)
                {
                // Clear the combobox
                this.leftMeterInstanceComboBox.Items.Clear();

                // Disable the combobox
                this.leftMeterInstanceComboBox.Enabled = false;
                }
            else
                {
                // Clear the combobox
                this.leftMeterInstanceComboBox.Items.Clear();

                // Populate the combobox
                foreach (string categoryInstance in instanceNames)
                    {
                    this.leftMeterInstanceComboBox.Items.Add(categoryInstance);
                    }

                // Select the first entry in the combobox if no item is selected
                if (String.Compare(Properties.Settings.Default.leftMeterInstanceFunction, Properties.Settings.Default.leftMeterFunction) == 0)
                    this.leftMeterInstanceComboBox.SelectedItem = Properties.Settings.Default.leftMeterInstance;
                else
                    {
                    this.leftMeterInstanceComboBox.SelectedIndex = 0;
                    Properties.Settings.Default.leftMeterInstance = leftMeterInstanceComboBox.SelectedItem.ToString();
                    Properties.Settings.Default.leftMeterInstanceFunction = Properties.Settings.Default.leftMeterFunction;
                    }

                // Enable the combobox
                this.leftMeterInstanceComboBox.Enabled = true;
                }
            }

        // Right meter methods
        private void rightMeterProcessorUtilisationRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (this.rightMeterProcessorUtilisationRadioButton.Checked == true)
                {
                Properties.Settings.Default.rightMeterFunction = "Processor";

                // Update the instances combobox
                setRightMeterInstance("Processor");
                if (rightMeterInstanceComboBox.SelectedItem != null)
                    Properties.Settings.Default.rightMeterInstance = rightMeterInstanceComboBox.SelectedItem.ToString();
                }
            }

        private void rightMeterHardDriveUtilisationRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (this.rightMeterHardDriveUtilisationRadioButton.Checked == true)
                {
                Properties.Settings.Default.rightMeterFunction = "Harddrive";

                // Update the instances combobox
                setRightMeterInstance("PhysicalDisk");
                if (rightMeterInstanceComboBox.SelectedItem != null)
                    Properties.Settings.Default.rightMeterInstance = rightMeterInstanceComboBox.SelectedItem.ToString();
                }
            }

        private void rightMeterMemoryUtilisationRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (this.rightMeterMemoryUtilisationRadioButton.Checked == true)
                {
                Properties.Settings.Default.rightMeterFunction = "Memory";

                // Update the instances combobox
                setRightMeterInstance("Memory");
                if (rightMeterInstanceComboBox.SelectedItem != null)
                    Properties.Settings.Default.rightMeterInstance = rightMeterInstanceComboBox.SelectedItem.ToString();
                }
            }

        private void rightMeterNetworkUtilisationRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (this.rightMeterNetworkUtilisationRadioButton.Checked == true)
                {
                Properties.Settings.Default.rightMeterFunction = "Network";

                // Update the instances combobox
                setRightMeterInstance("Network Interface");
                if (rightMeterInstanceComboBox.SelectedItem != null)
                    Properties.Settings.Default.rightMeterInstance = rightMeterInstanceComboBox.SelectedItem.ToString();

                // Enable the bandwidth override dialogue
                this.rightOverrideNetworkMaximumBandwidthCheckBox.Enabled = true;
                this.rightOverrideNetworkMaximumBandwidthMaskedTextBox.Enabled = true;
                this.rightMbitsSecLabel.Enabled = true;
                }
            else
                {
                // Disable the bandwidth override dialogue
                this.rightOverrideNetworkMaximumBandwidthCheckBox.Enabled = false;
                this.rightOverrideNetworkMaximumBandwidthMaskedTextBox.Enabled = false;
                this.rightMbitsSecLabel.Enabled = false;
                }
            }

        private void rightMeterDisabledRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (this.rightMeterDisabledRadioButton.Checked == true)
                {
                Properties.Settings.Default.rightMeterFunction = "Disabled";

                // Clear the combobox
                this.rightMeterInstanceComboBox.Items.Clear();

                // Disable the instance combobox
                this.rightMeterInstanceComboBox.Enabled = false;
                }
            }

        private void setRightMeterRadioButtons()
            {
            switch (Properties.Settings.Default.rightMeterFunction)
                {
                case "Processor":
                    this.rightMeterProcessorUtilisationRadioButton.Checked = true;

                    // Update the instances combobox
                    setRightMeterInstance("Processor");
                    this.rightMeterInstanceComboBox.SelectedItem = Properties.Settings.Default.rightMeterInstance;
                    break;

                case "Harddrive":
                    this.rightMeterHardDriveUtilisationRadioButton.Checked = true;

                    // Update the instances combobox
                    setRightMeterInstance("PhysicalDisk");
                    this.rightMeterInstanceComboBox.SelectedItem = Properties.Settings.Default.rightMeterInstance;
                    break;

                case "Memory":
                    this.rightMeterMemoryUtilisationRadioButton.Checked = true;

                    // Update the instances combobox
                    setRightMeterInstance("Memory");
                    this.rightMeterInstanceComboBox.SelectedItem = Properties.Settings.Default.rightMeterInstance;
                    break;

                case "Network":
                    this.rightMeterNetworkUtilisationRadioButton.Checked = true;

                    // Update the instances combobox
                    setRightMeterInstance("Network Interface");
                    this.rightMeterInstanceComboBox.SelectedItem = Properties.Settings.Default.rightMeterInstance;
                    break;

                case "Disabled":
                    this.rightMeterDisabledRadioButton.Checked = true;

                    // Disable the instance combobox
                    this.rightMeterInstanceComboBox.Enabled = false;
                    break;
                }
            }

        private void setRightMeterInstance(string counterCategory)
            {
            // Update the instances combobox
            string[] instanceNames;
            PerformanceCounterCategory myPerformanceCounterCategory =
                new PerformanceCounterCategory(counterCategory);

            instanceNames = myPerformanceCounterCategory.GetInstanceNames();

            if (instanceNames.Length == 0)
                {
                // Clear the combobox
                this.rightMeterInstanceComboBox.Items.Clear();

                // Disable the combobox
                this.rightMeterInstanceComboBox.Enabled = false;
                }
            else
                {
                // Clear the combobox
                this.rightMeterInstanceComboBox.Items.Clear();

                // Populate the combobox
                foreach (string categoryInstance in instanceNames)
                    {
                    this.rightMeterInstanceComboBox.Items.Add(categoryInstance);
                    }

                // Select the first entry in the combobox if no item is selected
                if (String.Compare(Properties.Settings.Default.rightMeterInstanceFunction, Properties.Settings.Default.rightMeterFunction) == 0)
                    this.rightMeterInstanceComboBox.SelectedItem = Properties.Settings.Default.rightMeterInstance;
                else
                    {
                    this.rightMeterInstanceComboBox.SelectedIndex = 0;
                    Properties.Settings.Default.rightMeterInstance = rightMeterInstanceComboBox.SelectedItem.ToString();
                    Properties.Settings.Default.rightMeterInstanceFunction = Properties.Settings.Default.rightMeterFunction;
                    }

                // Enable the combobox
                this.rightMeterInstanceComboBox.Enabled = true;
                }
            }

        // Hardware button radiobuttons
        private void buttonEnableDisableLedRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (buttonEnableDisableLedRadioButton.Checked == true)
                Properties.Settings.Default.buttonFunction = "Led";
            }

        private void buttonEnableDisableMetersRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (buttonEnableDisableMetersRadioButton.Checked == true)
                Properties.Settings.Default.buttonFunction = "Meters";
            }

        private void buttonEnableDisableMetersAndLedRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (buttonEnableDisableMetersAndLedRadioButton.Checked == true)
                Properties.Settings.Default.buttonFunction = "MetersAndLed";
            }

        private void buttonEnableDisableUsbRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (buttonEnableDisableUsbRadioButton.Checked == true)
                Properties.Settings.Default.buttonFunction = "Usb";
            }

        private void buttonNoActionRadioButton_CheckedChanged(object sender, EventArgs e)
            {
            if (buttonNoActionRadioButton.Checked == true)
                Properties.Settings.Default.buttonFunction = "None";
            }

        private void setButtonRadioButtons()
            {
            switch (Properties.Settings.Default.buttonFunction)
                {
                case "Led":
                    this.buttonEnableDisableLedRadioButton.Checked = true;
                    break;

                case "Meters":
                    this.buttonEnableDisableMetersRadioButton.Checked = true;
                    break;

                case "MetersAndLed":
                    this.buttonEnableDisableMetersAndLedRadioButton.Checked = true;
                    break;

                case "Usb":
                    this.buttonEnableDisableUsbRadioButton.Checked = true;
                    break;

                case "None":
                    this.buttonNoActionRadioButton.Checked = true;
                    break;
                }
            }

        // Instance combo box methods -------------------------------------------------------------------------------------------
        private void leftMeterInstanceComboBox_SelectedIndexChanged(object sender, EventArgs e)
            {
            if (leftMeterInstanceComboBox.SelectedItem != null)
                Properties.Settings.Default.leftMeterInstance = leftMeterInstanceComboBox.SelectedItem.ToString();
            }

        private void rightMeterInstanceComboBox_SelectedIndexChanged(object sender, EventArgs e)
            {
            if (rightMeterInstanceComboBox.SelectedItem != null)
                Properties.Settings.Default.rightMeterInstance = rightMeterInstanceComboBox.SelectedItem.ToString();
            }
        }
    }
