﻿//-----------------------------------------------------------------------------
//
//  usbPerformanceMeterDevice.cs
//
//  USB Performance Monitor Application
//  Copyright (C) 2010 Simon Inns
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//  Web:    http://www.waitingforfriday.com
//  Email:  simon.inns@gmail.com
//
//-----------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace USB_Performance_Monitor
    {
    using usbGenericHidCommunications;

    class usbPerformanceMeterDevice : usbGenericHidCommunication
        {
        public usbPerformanceMeterDevice(int vid, int pid)
            : base(vid, pid)
            {
            // Constructor
            }

        // Command to update the display
        public bool updateDevice(int leftMeterPercentage, int rightMeterPercentage,
            int ledRedValue, int ledGreenValue, int ledBlueValue, bool detachUsbOnButton)
            {
            bool buttonState = false;

            if (isDeviceAttached)
                {
                // Declare our output buffer
                Byte[] outputBuffer = new Byte[65];

                // Declare our input buffer
                Byte[] inputBuffer = new Byte[65];

                // Command 0x80: Update the device
                //          Byte[0] - Must be zero
                //			Byte[1] - The command 0x80
                //			Byte[2] - The left meter percentage 	(0-100) %
                //			Byte[3] - The right meter percentage	(0-100) %
                //			Byte[4] - The LED red value		    	(0-255) R
                //			Byte[5] - The LED green value			(0-255) G
                //			Byte[6] - The LED blue value			(0-255) B
                //          Byte[7] - Detach USB on button flag     (0-1) false, true

                outputBuffer[0] = 0;
                outputBuffer[1] = 0x80;
                outputBuffer[2] = (Byte)leftMeterPercentage;
                outputBuffer[3] = (Byte)rightMeterPercentage;
                outputBuffer[4] = (Byte)ledRedValue;
                outputBuffer[5] = (Byte)ledGreenValue;
                outputBuffer[6] = (Byte)ledBlueValue;

                if (detachUsbOnButton) outputBuffer[7] = 1;
                else outputBuffer[7] = 0;

                // Perform the write command
                bool success;
                success = writeRawReportToDevice(outputBuffer);

                // Now read back the button state from the device

                // Perform the read
                success = readSingleReportFromDevice(ref inputBuffer);

                // Was the read successful?
                if (!success) return false;

                // Set the returned button state flag
                if (inputBuffer[2] == 1) buttonState = true;
                else buttonState = false;
                }

            return buttonState;
            }

        // Command to update the display settings
        public void updateDeviceSettings(int leftMeterSensitivity, int rightMeterSensitivity, int ledFadeOn, int ledFadeOff)
            {
            if (isDeviceAttached)
                {
                // Declare our output buffer
                Byte[] outputBuffer = new Byte[65];

                // Command 0x81: Update the device settings
                //          Byte[ 0] - Must be zero
                //			Byte[ 1] - The command 0x81
                //			Byte[ 2] - The left meter sensitivity	    (0-100) %
                //			Byte[ 3] - The right meter sensitivity	    (0-100) %
                //			Byte[ 4] - The LED fade on value (lo-byte)	(0-255) microseconds
                //			Byte[ 5] - The LED fade on value (hi-byte)	(0-255) microseconds
                //			Byte[ 6] - The LED fade off value (lo-byte)	(0-255) microseconds
                //			Byte[ 7] - The LED fade off value (hi-byte)	(0-255) microseconds

                // Split the led fade time into bytes:
                int ledFadeOnHi = (ledFadeOn & 0xFF00) >> 8;
                int ledFadeOnLo = (ledFadeOn & 0x00FF);

                int ledFadeOffHi = (ledFadeOff & 0xFF00) >> 8;
                int ledFadeOffLo = (ledFadeOff & 0x00FF);

                outputBuffer[0] = 0;
                outputBuffer[1] = 0x81;
                outputBuffer[2] = (Byte)leftMeterSensitivity;
                outputBuffer[3] = (Byte)rightMeterSensitivity;
                outputBuffer[4] = (Byte)ledFadeOnLo;
                outputBuffer[5] = (Byte)ledFadeOnHi;
                outputBuffer[6] = (Byte)ledFadeOffLo;
                outputBuffer[7] = (Byte)ledFadeOffHi;

                // Perform the write command
                bool success;
                success = writeRawReportToDevice(outputBuffer);
                }
            }
        }
    }
